@@ -3,7 +3,7 @@ from sqlalchemy import create_engine
 class dbintf:
     """dbintf setup database connection info and establish an DB engine
     """
-    def __init__(db_name:str, user:str='postgres', password:str='password', host:str='localhost', port:str='5432', vendor:str='postgresql'):
+    def __init__(self, db_name:str, user:str='postgres', password:str='password', host:str='localhost', port:str='5432', vendor:str='postgresql'):
         """Setup database connection and establish an DB engine
 
         :param db_name: database name
@@ -17,4 +17,4 @@ class dbintf:
         self.user, self.password = user, password
         self.host, self.port, self.vendor = host, port, vendor
         self.sqlalchemy_url = f"{self.vendor}://{self.user}:{self.password}@{self.host}:{self.port}/{self.db_name}"
-        self.engine = create_engine(SQLALCHEMY_DATABASE_URL)
\ No newline at end of file
+        self.engine = create_engine(SQLALCHEMY_DATABASE_URL)
